@@ -58,7 +58,7 @@ func authLoginCmd(ctx *config.RunContext) *cobra.Command {
 			cmd.Println("We're redirecting you to our log in page, please complete that,\nand return here to continue using Infracost.")
 
 			auth := apiclient.AuthClient{Host: ctx.Config.DashboardEndpoint}
-			apiKey, info, err := auth.Login(ctx.ContextValues())
+			apiKey, info, err := auth.Login(ctx.ContextValues.Values())
 			if err != nil {
 				return err
 			}
