@@ -106,6 +106,13 @@ func commentGitLabCmd(ctx *config.RunContext) *cobra.Command {
 					return err
 				}
 
+				if res.Posted && ctx.IsCloudUploadExplicitlyEnabled() {
+					dashboardClient := apiclient.NewDashboardAPIClient(ctx)
+					if err := dashboardClient.SavePostedPrComment(ctx, commentOut.AddRunResponse.RunID, commentOut.Body); err != nil {
+						logging.Logger.Err(err).Msg("could not save posted PR comment")
+					}
+				}
+
 				pricingClient := apiclient.GetPricingAPIClient(ctx)
 				err = pricingClient.AddEvent("infracost-comment", ctx.EventEnv())
 				if err != nil {
@@ -117,7 +124,7 @@ func commentGitLabCmd(ctx *config.RunContext) *cobra.Command {
 					if err != nil {
 						return fmt.Errorf("failed to marshal result: %w", err)
 					}
-					cmd.Printf(string(b))
+					cmd.Print(string(b))
 				} else if res.Posted {
 					cmd.Println("Comment posted to GitLab")
 				} else {
