@@ -26,6 +26,7 @@ type generateConfigCommand struct {
 	templatePath string
 	template     string
 	outFile      string
+	treeFile     string
 }
 
 func newGenerateConfigCommand() *cobra.Command {
@@ -48,6 +49,7 @@ func newGenerateConfigCommand() *cobra.Command {
 	cmd.Flags().StringVar(&gen.template, "template", "", "Infracost template string that will generate the config-file yaml output")
 	cmd.Flags().StringVar(&gen.templatePath, "template-path", "", "Path to the Infracost template file that will generate the config-file yaml output")
 	cmd.Flags().StringVar(&gen.outFile, "out-file", "", "Save output to a file")
+	cmd.Flags().StringVar(&gen.treeFile, "tree-file", "", "Save a simplified tree of the detected projects and var files to a file")
 
 	return cmd
 }
@@ -103,6 +105,19 @@ func (g *generateConfigCommand) run(cmd *cobra.Command, args []string) error {
 		}
 	}
 
+	if g.treeFile != "" {
+		treeFile, err := os.Create(g.treeFile)
+		if err != nil {
+			logging.Logger.Warn().Msgf("could not create detected tree file: at %s %s", g.treeFile, err)
+		} else {
+			_, err = treeFile.WriteString(detectionOutput.Tree)
+			if err != nil {
+				logging.Logger.Warn().Msgf("could not write detected tree file: %s", err)
+			}
+			_ = treeFile.Close()
+		}
+	}
+
 	for _, provider := range detectionOutput.Providers {
 		if v, ok := provider.(hcl.DetectedProject); ok {
 			autoProjects = append(autoProjects, v)
