@@ -2,15 +2,35 @@ package main_test
 
 import (
 	"path"
+	"path/filepath"
 	"testing"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/infracost/infracost/internal/testutil"
 )
 
 func TestHCLMultiProjectInfra(t *testing.T) {
-	GoldenFileCommandTest(t, testutil.CalcGoldenFileTestdataDirName(),
-		[]string{"breakdown", "--config-file", path.Join("./testdata", testutil.CalcGoldenFileTestdataDirName(), "infracost.config.yml")},
-		nil)
+	name := testutil.CalcGoldenFileTestdataDirName()
+
+	t.Run("rel path", func(t *testing.T) {
+		GoldenFileCommandTest(t, name,
+			[]string{"breakdown", "--config-file", path.Join("./testdata", name, "infracost.config.yml")},
+			nil)
+	})
+
+	t.Run("abs path", func(t *testing.T) {
+		abs, err := filepath.Abs(path.Join("./testdata", name, "infracost.config.yml"))
+		require.NoError(t, err)
+
+		GoldenFileCommandTest(t, name,
+			[]string{
+				"breakdown",
+				"--config-file",
+				abs,
+			},
+			nil)
+	})
 }
 
 func TestHCLMultiWorkspace(t *testing.T) {
