@@ -5,6 +5,7 @@ import (
 	"encoding/hex"
 	"fmt"
 	"sort"
+	"strings"
 	"sync"
 
 	"github.com/hashicorp/go-retryablehttp"
@@ -49,6 +50,9 @@ func (c *PolicyAPIClient) UploadPolicyData(project *schema.Project, rds, pastRds
 		project.Metadata = &schema.ProjectMetadata{}
 	}
 
+	// remove .git suffix from the module path
+	project.Metadata.TerraformModulePath = strings.ReplaceAll(project.Metadata.TerraformModulePath, ".git/", "/")
+
 	err := c.fetchAllowList()
 	if err != nil {
 		return err
@@ -246,8 +250,9 @@ func filterResource(rd *schema.ResourceData, al allowList) policy2Resource {
 		return references[i].Key < references[j].Key
 	})
 
-	var mdCalls []policy2InfracostMetadataCall
-	for _, c := range rd.Metadata["calls"].Array() {
+	calls := rd.Metadata["calls"].Array()
+	mdCalls := make([]policy2InfracostMetadataCall, 0, len(calls))
+	for _, c := range calls {
 		mdCalls = append(mdCalls, policy2InfracostMetadataCall{
 			BlockName: c.Get("blockName").String(),
 			EndLine:   c.Get("endLine").Int(),
