@@ -43,6 +43,19 @@ type AutodetectConfig struct {
 	// var files. This is useful when there are non-standard terraform var file
 	// names which use different extensions.
 	TerraformVarFileExtensions []string `yaml:"terraform_var_file_extensions,omitempty" ignored:"true"`
+	// PreferFolderNameForEnv tells the autodetect to prefer the folder name over the
+	// over a env specified in a tfvars file. For example, given the following
+	// folder structure:
+	//
+	// .
+	// ├── qa
+	// │   └── dev.tfvars
+	// └── staging
+	//     └── prod.tfvars
+	//
+	// If PreferFolderNameForEnv is true, then the autodetect will group the projects
+	// by the folder name so the projects will be named "qa" and "staging".
+	PreferFolderNameForEnv bool `yaml:"prefer_folder_name_for_env,omitempty" ignored:"true"`
 }
 
 type PathOverride struct {
@@ -159,6 +172,14 @@ type Config struct {
 	// TerraformSourceMap replaces any source URL with the provided value.
 	TerraformSourceMap TerraformSourceMap `envconfig:"TERRAFORM_SOURCE_MAP"`
 
+	S3ModuleCacheRegion  string `envconfig:"S3_MODULE_CACHE_REGION"`
+	S3ModuleCacheBucket  string `envconfig:"S3_MODULE_CACHE_BUCKET"`
+	S3ModuleCachePrefix  string `envconfig:"S3_MODULE_CACHE_PREFIX"`
+	S3ModuleCachePrivate bool   `envconfig:"S3_MODULE_CACHE_PRIVATE, default=false"`
+
+	// metrics dump path
+	MetricsPath string `envconfig:"METRICS_PATH"`
+
 	// Org settings
 	EnableCloudForOrganization bool
 
