@@ -19,6 +19,7 @@ import (
 	"github.com/zclconf/go-cty/cty/gocty"
 
 	"github.com/infracost/infracost/internal/hcl/funcs"
+	"github.com/infracost/infracost/internal/hcl/mock"
 	"github.com/infracost/infracost/internal/hcl/modules"
 )
 
@@ -828,7 +829,7 @@ func (b *Block) Children() Blocks {
 		return nil
 	}
 
-	var children Blocks
+	children := make(Blocks, 0, len(b.childBlocks))
 	for _, child := range b.childBlocks {
 		// Skip lifecycle meta argument blocks since it never needs to be evaluated
 		if supportsLifecycle(child) && child.Type() == "lifecycle" {
@@ -886,7 +887,7 @@ func (b *Block) GetAttributes() []*Attribute {
 				Logger: b.logger.With().Str(
 					"attribute_name", k,
 				).Logger(),
-				isGraph: b.isGraph,
+				IsGraph: b.isGraph,
 			})
 			continue
 		}
@@ -899,7 +900,7 @@ func (b *Block) GetAttributes() []*Attribute {
 			Logger: b.logger.With().Str(
 				"attribute_name", hclAttributes[k].Name,
 			).Logger(),
-			isGraph: b.isGraph,
+			IsGraph: b.isGraph,
 		})
 	}
 
@@ -957,7 +958,7 @@ func (b *Block) syntheticAttribute(name string, val cty.Value) *Attribute {
 		Logger: b.logger.With().Str(
 			"attribute_name", name,
 		).Logger(),
-		isGraph: b.isGraph,
+		IsGraph: b.isGraph,
 	}
 }
 
@@ -1381,6 +1382,7 @@ var (
 		"data.google_compute_zones":    googleComputeZonesValues,
 		"data.aws_region":              awsCurrentRegion,
 		"data.aws_default_tags":        awsDefaultTagValues,
+		"data.aws_subnets":             awsSubnetsValues,
 		"resource.random_shuffle":      randomShuffleValues,
 		"resource.time_static":         timeStaticValues,
 		"resource.aws_launch_template": launchTemplateValues,
@@ -1464,6 +1466,23 @@ func awsDefaultTagValues(b *Block) cty.Value {
 	})
 }
 
+// awsSubnetsValues mocks the values returned from data.aws_subnets. This data
+// source returns a list of subnet IDs.
+// https://registry.terraform.io/providers/hashicorp/aws/latest/docs/data-sources/subnets
+//
+// We return a list of 3 fake subnet IDs. Although the actual number of subnets
+// returned is based on the region and availability zones, we return a fixed
+// "sensible" number.
+func awsSubnetsValues(b *Block) cty.Value {
+	return cty.ObjectVal(map[string]cty.Value{
+		"ids": cty.ListVal([]cty.Value{
+			cty.StringVal(fmt.Sprintf("subnet-1-%s", mock.Identifier)),
+			cty.StringVal(fmt.Sprintf("subnet-2-%s", mock.Identifier)),
+			cty.StringVal(fmt.Sprintf("subnet-3-%s", mock.Identifier)),
+		}),
+	})
+}
+
 // randomShuffleValues mocks the values returned from resource.random_shuffle
 // https://github.com/hashicorp/terraform-provider-random/blob/main/docs/resources/shuffle.md.
 // This resource uses the result_count attribute to return a slice of the input
