@@ -239,6 +239,7 @@ func (e *Evaluator) MissingVars() []string {
 // this Module.
 func (e *Evaluator) Run() (*Module, error) {
 	var lastContext hcl.EvalContext
+
 	// first we need to evaluate the top level Context - so this can be passed to any child modules that are found.
 	e.logger.Debug().Msg("evaluating top level context")
 	e.evaluate(lastContext)
@@ -1242,12 +1243,12 @@ func ExpFunctions(baseDir string, logger zerolog.Logger) map[string]function.Fun
 		"timestamp":        funcs.MockTimestampFunc, // custom. We want to return a deterministic value each time
 		"timeadd":          stdlib.TimeAddFunc,
 		"title":            stdlib.TitleFunc,
-		"tostring":         componentsFuncs.MakeToFunc(cty.String),
-		"tonumber":         componentsFuncs.MakeToFunc(cty.Number),
-		"tobool":           componentsFuncs.MakeToFunc(cty.Bool),
-		"toset":            componentsFuncs.MakeToFunc(cty.Set(cty.DynamicPseudoType)),
-		"tolist":           componentsFuncs.MakeToFunc(cty.List(cty.DynamicPseudoType)),
-		"tomap":            componentsFuncs.MakeToFunc(cty.Map(cty.DynamicPseudoType)),
+		"tostring":         funcs.MakeToFunc(cty.String),
+		"tonumber":         funcs.MakeToFunc(cty.Number),
+		"tobool":           funcs.MakeToFunc(cty.Bool),
+		"toset":            funcs.MakeToFunc(cty.Set(cty.DynamicPseudoType)),
+		"tolist":           funcs.MakeToFunc(cty.List(cty.DynamicPseudoType)),
+		"tomap":            funcs.MakeToFunc(cty.Map(cty.DynamicPseudoType)),
 		"transpose":        componentsFuncs.TransposeFunc,
 		"trim":             stdlib.TrimFunc,
 		"trimprefix":       stdlib.TrimPrefixFunc,
