@@ -65,6 +65,14 @@ var (
 		".tfvars.json",
 		".auto.tfvars.json",
 	}
+	defaultExcludedDirs = []string{
+		".infracost",
+		".git",
+		".terraform",
+		".terragrunt-cache",
+		"example",
+		"examples",
+	}
 )
 
 // EnvFileMatcher is used to match environment specific var files.
@@ -92,15 +100,15 @@ func CreateEnvFileMatcher(names []string, extensions []string) *EnvFileMatcher {
 		return len(extensions[i]) > len(extensions[j])
 	})
 
-	var envNames []string
+	envNames := make([]string, 0, len(names))
 	var wildcards []string
 	for _, name := range names {
 		// envNames can contain wildcards, we need to handle them separately. e.g: dev-*
 		// will create separate envs for dev-staging and dev-legacy. We don't want these
 		// wildcards to appear in the envNames list as this will create unwanted env
 		// grouping.
-		if strings.Contains(name, "*") {
-			wildcards = append(wildcards, name)
+		if strings.Contains(name, "*") || strings.Contains(name, "?") {
+			wildcards = append(wildcards, strings.ToLower(name))
 			continue
 		}
 
@@ -121,6 +129,30 @@ func CreateEnvFileMatcher(names []string, extensions []string) *EnvFileMatcher {
 	}
 }
 
+func createWildcardGlobPaths(dirs []string) []string {
+	paths := make([]string, 0, len(dirs)*2)
+	for _, dir := range dirs {
+		paths = append(paths, path.Join(dir, "**"))
+	}
+
+	for _, dir := range dirs {
+		paths = append(paths, path.Join("**", path.Join(dir, "**")))
+	}
+
+	return paths
+}
+
+func isDefaultExcluded(name string) bool {
+	for _, dir := range defaultExcludedDirs {
+		if dir == name {
+			return true
+		}
+	}
+
+	return false
+
+}
+
 // IsAutoVarFile checks if the var file is an auto.tfvars or terraform.tfvars.
 // These are special Terraform var files that are applied to every project
 // automatically.
@@ -219,6 +251,18 @@ func (e *EnvFileMatcher) EnvName(file string) string {
 	return clean
 }
 
+// PathEnv returns the env name detected in file path when it matches defined envs. Otherwise returns an empty string.
+func (e *EnvFileMatcher) PathEnv(file string) string {
+	env := e.EnvName(file)
+
+	_, ok := e.envLookup[env]
+	if ok {
+		return env
+	}
+
+	return ""
+}
+
 func (e *EnvFileMatcher) hasEnvPrefix(clean string, name string) bool {
 	return strings.HasPrefix(clean, name+"-") || strings.HasPrefix(clean, name+"_") || strings.HasPrefix(clean, name+".")
 }
@@ -270,6 +314,7 @@ type ProjectLocator struct {
 	hclParser                  *hclparse.Parser
 	hasCustomEnvExt            bool
 	workingDirectory           string
+	preferFolderNameForEnv     bool
 }
 
 // ProjectLocatorConfig provides configuration options on how the locator functions.
@@ -286,6 +331,7 @@ type ProjectLocatorConfig struct {
 	ForceProjectType           string
 	TerraformVarFileExtensions []string
 	WorkingDirectory           string
+	PreferFolderNameForEnv     bool
 }
 
 type PathOverrideConfig struct {
@@ -345,7 +391,7 @@ func NewProjectLocator(logger zerolog.Logger, config *ProjectLocatorConfig) *Pro
 			modules:            make(map[string]struct{}),
 			moduleCalls:        make(map[string][]string),
 			discoveredVarFiles: make(map[string][]RootPathVarFile),
-			excludedDirs:       config.ExcludedDirs,
+			excludedDirs:       append(createWildcardGlobPaths(defaultExcludedDirs), config.ExcludedDirs...),
 			changedObjects:     config.ChangedObjects,
 			includedDirs:       config.IncludedDirs,
 			pathOverrides:      overrides,
@@ -366,6 +412,7 @@ func NewProjectLocator(logger zerolog.Logger, config *ProjectLocatorConfig) *Pro
 			hclParser:                  hclparse.NewParser(),
 			hasCustomEnvExt:            len(config.TerraformVarFileExtensions) > 0,
 			workingDirectory:           config.WorkingDirectory,
+			preferFolderNameForEnv:     config.PreferFolderNameForEnv,
 		}
 	}
 
@@ -437,7 +484,7 @@ type VarFiles struct {
 
 // CreateTreeNode creates a tree of Terraform projects and directories that
 // contain var files.
-func CreateTreeNode(basePath string, paths []RootPath, varFiles map[string][]RootPathVarFile, e *EnvFileMatcher) *TreeNode {
+func CreateTreeNode(basePath string, paths []RootPath, varFiles map[string][]RootPathVarFile, e *EnvFileMatcher, preferFolderNameForEnv bool) *TreeNode {
 	root := &TreeNode{
 		Name: "root",
 	}
@@ -450,7 +497,7 @@ func CreateTreeNode(basePath string, paths []RootPath, varFiles map[string][]Roo
 		root.AddPath(path)
 	}
 
-	var varFilesSorted []string
+	varFilesSorted := make([]string, 0, len(varFiles))
 	for dir := range varFiles {
 		varFilesSorted = append(varFilesSorted, dir)
 	}
@@ -462,14 +509,14 @@ func CreateTreeNode(basePath string, paths []RootPath, varFiles map[string][]Roo
 		root.AddTerraformVarFiles(basePath, dir, varFiles[dir])
 	}
 
-	buildVarFileEnvNames(root, e)
+	buildVarFileEnvNames(root, e, preferFolderNameForEnv)
 	return root
 }
 
 // buildVarFileEnvNames builds the EnvName field for each var file. Var names
 // can be inferred from the filename or from parent directories, but only if
 // the parent directories don't contain any Terraform projects.
-func buildVarFileEnvNames(root *TreeNode, e *EnvFileMatcher) {
+func buildVarFileEnvNames(root *TreeNode, e *EnvFileMatcher, preferFolderNameForEnv bool) {
 	root.PostOrder(func(t *TreeNode) {
 		if t.TerraformVarFiles == nil {
 			return
@@ -499,12 +546,27 @@ func buildVarFileEnvNames(root *TreeNode, e *EnvFileMatcher) {
 		}
 
 		for i, f := range t.TerraformVarFiles.Files {
-			namesToSearch := append([]string{f.Name}, possibleEnvNames...)
 			var envName string
-			for _, search := range namesToSearch {
-				if e.IsEnvName(search) {
-					envName = search
-					break
+			if preferFolderNameForEnv {
+				// First try to find env name from parent directories
+				for _, search := range possibleEnvNames {
+					if e.IsEnvName(search) {
+						envName = search
+						break
+					}
+				}
+
+				// If no env name found in parent directories, fallback to file name
+				if envName == "" && e.IsEnvName(f.Name) {
+					envName = f.Name
+				}
+			} else {
+				namesToSearch := append([]string{f.Name}, possibleEnvNames...)
+				for _, search := range namesToSearch {
+					if e.IsEnvName(search) {
+						envName = search
+						break
+					}
 				}
 			}
 
@@ -516,6 +578,99 @@ func buildVarFileEnvNames(root *TreeNode, e *EnvFileMatcher) {
 	})
 }
 
+// PrintTree prints a simplified tree of the detected projects and var files
+// similar to a linux tree command.
+func (t *TreeNode) PrintTree() string {
+	var sb strings.Builder
+	t.printTreeWithPrefix(&sb, "", true)
+	return sb.String()
+}
+
+// printTreeWithPrefix is a helper function that recursively prints the tree structure
+func (t *TreeNode) printTreeWithPrefix(sb *strings.Builder, prefix string, isLast bool) {
+	// Skip the root node as it's just a container
+	if t.Name != "root" {
+		if isLast {
+			sb.WriteString(prefix + "└── ")
+		} else {
+			sb.WriteString(prefix + "├── ")
+		}
+
+		sb.WriteString(t.Name)
+		if t.RootPath != nil {
+			if t.RootPath.IsTerragrunt {
+				sb.WriteString(" (terragrunt")
+			} else {
+				sb.WriteString(" (terraform")
+			}
+
+			if t.RootPath.IsParentTerragruntConfig {
+				sb.WriteString(", parent")
+			}
+			sb.WriteString(")")
+
+			if len(t.RootPath.TerraformVarFiles) > 0 {
+				t.printVarFiles(t.RootPath.TerraformVarFiles, sb, prefix, isLast)
+			}
+		}
+
+		if t.TerraformVarFiles != nil {
+			t.printVarFiles(t.TerraformVarFiles.Files, sb, prefix, isLast)
+		}
+		sb.WriteString("\n")
+	}
+
+	newPrefix := prefix
+	if t.Name != "root" {
+		if isLast {
+			newPrefix += "    "
+		} else {
+			newPrefix += "│   "
+		}
+	}
+
+	// Sort children alphabetically
+	sortedChildren := make([]*TreeNode, len(t.Children))
+	copy(sortedChildren, t.Children)
+	sort.Slice(sortedChildren, func(i, j int) bool {
+		return sortedChildren[i].Name < sortedChildren[j].Name
+	})
+
+	for i, child := range sortedChildren {
+		child.printTreeWithPrefix(sb, newPrefix, i == len(sortedChildren)-1)
+	}
+}
+
+func (t *TreeNode) printVarFiles(files []RootPathVarFile, sb *strings.Builder, prefix string, isLast bool) {
+	sb.WriteString("\n")
+	sortedFiles := make([]RootPathVarFile, len(files))
+	copy(sortedFiles, files)
+
+	sort.Slice(sortedFiles, func(i, j int) bool {
+		return sortedFiles[i].Name < sortedFiles[j].Name
+	})
+
+	for i, f := range sortedFiles {
+		lastVarFile := i == len(sortedFiles)-1
+
+		varFilePrefix := prefix + "│   "
+		if isLast {
+			varFilePrefix = prefix + "    "
+		}
+
+		suffix := "\n"
+
+		if lastVarFile {
+			suffix = ""
+			sb.WriteString(varFilePrefix + "└── ")
+		} else {
+			sb.WriteString(varFilePrefix + "├── ")
+		}
+
+		sb.WriteString(f.Name + suffix)
+	}
+}
+
 // AddPath adds a path to the tree, this will create any missing nodes in the tree.
 func (t *TreeNode) AddPath(path RootPath) {
 	dir, _ := filepath.Rel(path.StartingPath, path.DetectedPath)
@@ -584,6 +739,19 @@ func (t *TreeNode) ParentNode() *TreeNode {
 	return nil
 }
 
+// Parents returns the list of parent nodes of the current node.
+func (t *TreeNode) Parents() []*TreeNode {
+	var parents []*TreeNode
+	parent := t.ParentNode()
+
+	for parent != nil {
+		parents = append(parents, parent)
+		parent = parent.ParentNode()
+	}
+
+	return parents
+}
+
 // UnusedParentVarFiles returns a list of any parent directories that contain var
 // files that have not been used by a project.
 func (t *TreeNode) UnusedParentVarFiles() []*VarFiles {
@@ -916,8 +1084,8 @@ func (t *TreeNode) CollectRootPaths(e *EnvFileMatcher) []RootPath {
 
 	found := make(map[string]bool)
 	for _, root := range projects {
+		base := filepath.Base(root.DetectedPath)
 		for _, varFile := range root.TerraformVarFiles {
-			base := filepath.Base(root.DetectedPath)
 			name := e.clean(varFile.Name)
 			if base == name {
 				found[varFile.FullPath] = true
@@ -930,10 +1098,11 @@ func (t *TreeNode) CollectRootPaths(e *EnvFileMatcher) []RootPath {
 	// terraform var files that are scoped to a specific project
 	// are not added to another project.
 	for i, root := range projects {
+		base := filepath.Base(root.DetectedPath)
+
 		var filtered RootPathVarFiles
 		for _, varFile := range root.TerraformVarFiles {
 			name := e.clean(varFile.Name)
-			base := filepath.Base(root.DetectedPath)
 			if found[varFile.FullPath] && base != name {
 				continue
 			}
@@ -962,9 +1131,10 @@ type RootPath struct {
 	// TerraformVarFiles are a list of any .tfvars or .tfvars.json files found at the root level.
 	TerraformVarFiles RootPathVarFiles
 
-	HasChildVarFiles bool
-	IsTerragrunt     bool
-	ModuleCalls      []string
+	HasChildVarFiles         bool
+	IsTerragrunt             bool
+	IsParentTerragruntConfig bool
+	ModuleCalls              []string
 }
 
 func (r *RootPath) RelPath() string {
@@ -1035,6 +1205,7 @@ func (r *RootPath) EnvGroupings() []VarFileGrouping {
 		}
 	}
 
+	pathEnv := r.Matcher.PathEnv(r.DetectedPath)
 	hasChildVarFileEnvs := len(varFileGrouping) > 0
 
 	for _, varFile := range varFiles {
@@ -1044,6 +1215,11 @@ func (r *RootPath) EnvGroupings() []VarFileGrouping {
 
 		env := r.Matcher.EnvName(varFile.EnvName)
 		_, exists := varFileGrouping[env]
+
+		// When env is a part of the project name, we should ignore any other detected envs
+		if pathEnv != "" && env != pathEnv {
+			continue
+		}
 		// only add the non child env var files if there are no envs defined that are
 		// closer to the project, or if the env matches one defined as a child var file.
 		if !hasChildVarFileEnvs || (hasChildVarFileEnvs && exists) {
@@ -1051,13 +1227,13 @@ func (r *RootPath) EnvGroupings() []VarFileGrouping {
 		}
 	}
 
-	var envNames []string
+	envNames := make([]string, 0, len(varFileGrouping))
 	for env := range varFileGrouping {
 		envNames = append(envNames, env)
 	}
 	sort.Strings(envNames)
 
-	var varEnvs []VarFileGrouping
+	varEnvs := make([]VarFileGrouping, 0, len(envNames))
 	for _, env := range envNames {
 		varEnvs = append(varEnvs, VarFileGrouping{
 			Name:              env,
@@ -1111,7 +1287,7 @@ func (r *RootPath) AddVarFiles(v *VarFiles) {
 // FindRootModules returns a list of all directories that contain a full
 // Terraform project under the given fullPath. This list excludes any Terraform
 // modules that have been found (if they have been called by a Module source).
-func (p *ProjectLocator) FindRootModules(startingPath string) []RootPath {
+func (p *ProjectLocator) FindRootModules(startingPath string) ([]RootPath, string) {
 	p.basePath, _ = filepath.Abs(startingPath)
 	p.modules = make(map[string]struct{})
 	p.projectDuplicates = make(map[string]bool)
@@ -1141,11 +1317,12 @@ func (p *ProjectLocator) FindRootModules(startingPath string) []RootPath {
 				IsTerragrunt:      p.wdContainsTerragrunt,
 				TerraformVarFiles: p.discoveredVarFiles[startingPath],
 			},
-		}
+		}, ""
 	}
 
 	p.findTerragruntDirs(startingPath)
 	p.walkPaths(startingPath, 0, p.maxSearchDepth())
+
 	for _, project := range p.discoveredProjects {
 		if _, ok := p.projectDuplicates[project.path]; ok {
 			p.projectDuplicates[project.path] = true
@@ -1194,7 +1371,9 @@ func (p *ProjectLocator) FindRootModules(startingPath string) []RootPath {
 		delete(p.discoveredVarFiles, dir.DetectedPath)
 	}
 
-	node := CreateTreeNode(startingPath, projects, p.discoveredVarFiles, p.envMatcher)
+	node := CreateTreeNode(startingPath, projects, p.discoveredVarFiles, p.envMatcher, p.preferFolderNameForEnv)
+	tree := node.PrintTree()
+
 	node.AssociateChildVarFiles()
 	node.AssociateSiblingVarFiles()
 	node.AssociateParentVarFiles()
@@ -1217,7 +1396,7 @@ func (p *ProjectLocator) FindRootModules(startingPath string) []RootPath {
 		return paths[i].DetectedPath < paths[j].DetectedPath
 	})
 
-	return paths
+	return paths, tree
 }
 
 // excludeEnvFromPaths filters car files from the paths based on the path overrides.
@@ -1280,16 +1459,14 @@ func (p *ProjectLocator) discoveredProjectsWithModulesFiltered() []discoveredPro
 }
 
 func (p *ProjectLocator) shouldUseProject(dir discoveredProject, force bool) bool {
-	if p.shouldSkipDir(dir.path) {
-		p.logger.Debug().Msgf("skipping directory %s as it is marked as excluded by --exclude-path", dir.path)
+	// if the directory is marked as excluded and not included we skip it.
+	// The include_dirs setting takes precedence over exclude_dirs.
+	if p.shouldSkipDir(dir.path) && !p.shouldIncludeDir(dir.path) {
+		p.logger.Trace().Msgf("skipping directory %s as it is marked as excluded by --exclude-path", dir.path)
 
 		return false
 	}
 
-	if force {
-		return true
-	}
-
 	if p.shouldIncludeDir(dir.path) {
 		return true
 	}
@@ -1298,6 +1475,10 @@ func (p *ProjectLocator) shouldUseProject(dir discoveredProject, force bool) boo
 		return false
 	}
 
+	if force {
+		return true
+	}
+
 	// we only include Terraform projects that have been found alongside Terragrunt
 	// projects if they have been forced to be included by --include-path. This is
 	// done as we sometimes get collisions with the Terragrunt modules that are
@@ -1469,7 +1650,8 @@ func (p *ProjectLocator) walkPaths(fullPath string, level int, maxSearchDepth in
 		if info.IsDir() {
 			fullPath := filepath.Join(fullPath, info.Name())
 
-			if strings.HasPrefix(info.Name(), ".") && !p.shouldIncludeDir(fullPath) {
+			// if the directory is one of the known excluded directories we skip it.
+			if isDefaultExcluded(info.Name()) && !p.shouldIncludeDir(fullPath) {
 				continue
 			}
 
@@ -1661,6 +1843,7 @@ func (p *ProjectLocator) findTerragruntDirs(fullPath string) {
 	terragruntConfigFiles, err := tgconfig.FindConfigFilesInPath(fullPath, &options.TerragruntOptions{
 		DownloadDir: terragruntDownloadDir,
 	})
+
 	if err != nil {
 		p.logger.Debug().Err(err).Msgf("failed to find terragrunt files in path %s", fullPath)
 	}
@@ -1669,19 +1852,110 @@ func (p *ProjectLocator) findTerragruntDirs(fullPath string) {
 		p.wdContainsTerragrunt = true
 	}
 
-	for _, configFile := range terragruntConfigFiles {
-		if !p.shouldSkipDir(filepath.Dir(configFile)) && !IsParentTerragruntConfig(configFile, terragruntConfigFiles) {
+	for _, project := range p.removeParentTerragruntFiles(fullPath, terragruntConfigFiles) {
+		if !p.shouldSkipDir(filepath.Dir(project)) {
 			p.discoveredProjects = append(p.discoveredProjects, discoveredProject{
-				path:         filepath.Dir(configFile),
+				path:         project,
 				isTerragrunt: true,
 			})
 		}
 	}
 }
 
+// removeParentTerragruntFiles removes any parent Terragrunt config files from
+// the list of discovered Terragrunt configuration files.
+func (p *ProjectLocator) removeParentTerragruntFiles(startingPath string, files []string) []string {
+	paths := make([]RootPath, 0, len(files))
+	nameMap := make(map[string]string)
+	for _, file := range files {
+		dir := filepath.Dir(file)
+		nameMap[dir] = filepath.Base(file)
+
+		paths = append(paths, RootPath{
+			DetectedPath: dir,
+			StartingPath: startingPath,
+		})
+	}
+
+	var projects []string
+	root := CreateTreeNode(startingPath, paths, nil, nil, p.preferFolderNameForEnv)
+
+	// We need to slightly modify the TreeNode behaviour so that it works for this Terragrunt
+	// use case. For this case if there is a detected Terragrunt config file in the root of the
+	// directory we need to set it on the Root node so that we can traverse the tree and mark
+	// all parent nodes as parent Terragrunt config files.
+	var rootChildren []*TreeNode
+	for _, child := range root.Children {
+		if child.Name == "." && child.RootPath != nil {
+			root.RootPath = child.RootPath
+		} else {
+			rootChildren = append(rootChildren, child)
+		}
+	}
+	root.Children = rootChildren
+
+	root.PostOrder(func(t *TreeNode) {
+		if p.shouldSkipDir(filepath.Dir(t.RootPath.DetectedPath)) {
+			return
+		}
+
+		if t.RootPath.IsParentTerragruntConfig {
+			// If the current node is a parent terragrunt config, we can skip processing it.
+			return
+		}
+
+		parent := t.ParentNode()
+		if parent == nil {
+			// no valid parent node so no need to process this child node.
+			return
+		}
+
+		if parent.RootPath != nil && parent.RootPath.IsParentTerragruntConfig {
+			// no need to process this child node as the parent has already been marked as a parent terragrunt config.
+			return
+		}
+
+		filename := nameMap[t.RootPath.DetectedPath]
+		if p.processFile(filepath.Join(t.RootPath.DetectedPath, filename)) {
+			// Mark all parent nodes as parent terragrunt config of the current node.
+			parents := t.Parents()
+			for _, v := range parents {
+				if v != nil && v.RootPath != nil {
+					v.RootPath.IsParentTerragruntConfig = true
+				}
+			}
+		}
+	})
+
+	root.Visit(func(t *TreeNode) {
+		if t.RootPath != nil && !t.RootPath.IsParentTerragruntConfig {
+			projects = append(projects, t.RootPath.DetectedPath)
+		}
+	})
+
+	return projects
+}
+
+func (p *ProjectLocator) processFile(name string) bool {
+	file, err := os.Open(name)
+	if err != nil {
+		return false
+	}
+	defer file.Close()
+
+	scanner := bufio.NewScanner(file)
+	for scanner.Scan() {
+		if strings.Contains(scanner.Text(), "find_in_parent_folders()") {
+			return true
+		}
+	}
+
+	return false
+}
+
 func buildDirMatcher(dirs []string, fullPath string) func(string) bool {
 	var rawMatches []string
-	globMatches := make(map[string]struct{})
+	globMatchers := []glob.Glob{}
 
 	for _, dir := range dirs {
 		var absoluteDir string
@@ -1695,17 +1969,19 @@ func buildDirMatcher(dirs []string, fullPath string) func(string) bool {
 			absoluteDir = filepath.Join(fullPath, dir)
 		}
 
-		globs, err := filepath.Glob(absoluteDir)
-		if err == nil {
-			for _, m := range globs {
-				globMatches[m] = struct{}{}
-			}
+		g, err := glob.Compile(absoluteDir)
+		if err != nil {
+			continue
 		}
+
+		globMatchers = append(globMatchers, g)
 	}
 
 	return func(dir string) bool {
-		if _, ok := globMatches[dir]; ok {
-			return true
+		for _, g := range globMatchers {
+			if g.Match(dir) {
+				return true
+			}
 		}
 
 		base := filepath.Base(dir)
@@ -1718,53 +1994,3 @@ func buildDirMatcher(dirs []string, fullPath string) func(string) bool {
 		return false
 	}
 }
-
-// IsParentTerragruntConfig checks if a terragrunt config entry is a parent file that is referenced by another config
-// with a find_in_parent_folders call. The find_in_parent_folders function searches up the directory tree
-// from the file and returns the absolute path to the first terragrunt.hcl. This means if it is found
-// we can treat this file as a child terragrunt.hcl.
-func IsParentTerragruntConfig(parent string, configFiles []string) bool {
-	for _, name := range configFiles {
-		if !isChildDirectory(parent, name) {
-			continue
-		}
-
-		file, err := os.Open(name)
-		if err != nil {
-			continue
-		}
-
-		scanner := bufio.NewScanner(file)
-		for scanner.Scan() {
-			line := strings.TrimSpace(scanner.Text())
-			// skip any commented out lines
-			if strings.HasPrefix(line, "#") {
-				continue
-			}
-
-			if strings.Contains(line, "find_in_parent_folders()") {
-				file.Close()
-				return true
-			}
-		}
-
-		file.Close()
-	}
-
-	return false
-}
-
-func isChildDirectory(parent, child string) bool {
-	if parent == child {
-		return false
-	}
-
-	parentDir := filepath.Dir(parent)
-	childDir := filepath.Dir(child)
-	p, err := filepath.Rel(parentDir, childDir)
-	if err != nil || strings.Contains(p, "..") {
-		return false
-	}
-
-	return true
-}
