@@ -17,6 +17,7 @@ import (
 	spaceliftSession "github.com/spacelift-io/spacectl/client/session"
 	"github.com/spacelift-io/spacectl/client/structs"
 	"github.com/zclconf/go-cty/cty"
+	ctyJson "github.com/zclconf/go-cty/cty/json"
 
 	"github.com/infracost/infracost/internal/extclient"
 	"github.com/infracost/infracost/internal/logging"
@@ -120,8 +121,9 @@ func NewTFCRemoteVariablesLoader(client *extclient.AuthedAPIClient, localWorkspa
 }
 
 type RemoteVarLoaderOptions struct {
-	Blocks  Blocks
-	EnvName string
+	Blocks      Blocks
+	ModulePath  string
+	Environment string
 }
 
 // Load fetches remote variables if terraform block contains organization and
@@ -377,7 +379,8 @@ type SpaceliftRemoteVariableLoader struct {
 	Client   client.Client
 	Metadata vcs.Metadata
 
-	cache *sync.Map
+	cache  *sync.Map
+	hitMap *sync.Map
 }
 
 // NewSpaceliftRemoteVariableLoader creates a new SpaceliftRemoteVariableLoader, this function
@@ -394,14 +397,15 @@ func NewSpaceliftRemoteVariableLoader(metadata vcs.Metadata, apiKeyEndpoint, api
 		Client:   client.New(httpClient, session),
 		Metadata: metadata,
 		cache:    &sync.Map{},
+		hitMap:   &sync.Map{},
 	}, nil
 }
 
 // Load fetches remote variables from Spacelift by querying the stacks for the
 // provided environment name and remote name.
 func (s *SpaceliftRemoteVariableLoader) Load(options RemoteVarLoaderOptions) (map[string]cty.Value, error) {
-	if options.EnvName == "" {
-		logging.Logger.Trace().Msg("no environment name provided, skipping Spacelift remote variable loading")
+	if options.ModulePath == "" {
+		logging.Logger.Trace().Msg("no module path provided, skipping Spacelift remote variable loading")
 		return nil, nil
 	}
 
@@ -409,39 +413,91 @@ func (s *SpaceliftRemoteVariableLoader) Load(options RemoteVarLoaderOptions) (ma
 	// in future we should get all stacks for the remote name and then
 	// dynamically create projects out of the stacks returned.
 	stacks, err := s.getStacks(context.Background(), &getStackOptions{
-		count:          1,
+		count:          10, // We only want 1 stack, but want to filter by the module suffix
 		repositoryName: s.Metadata.Remote.Name,
-		name:           options.EnvName,
+		projectRoot:    options.ModulePath,
 	})
 	if err != nil {
-		return nil, fmt.Errorf("could not get stacks: %w", err)
+		return nil, fmt.Errorf("could not get Spacelift stacks: %w", err)
 	}
 
-	var stackEnvs []stackConfig
-	for _, s := range stacks {
-		if s.Name == options.EnvName {
-			stackEnvs = s.Config
-			break
-		}
-	}
-
-	if len(stackEnvs) == 0 {
-		logging.Logger.Trace().Msg("no stack environments found, skipping Spacelift remote variable loading")
+	if len(stacks) == 0 {
+		logging.Logger.Debug().Msgf("no Spacelift stack found for module path %q", options.ModulePath)
 		return nil, nil
 	}
 
+	// If there is a module suffix, filter the stacks by it
+	if options.Environment != "" {
+		var filteredStacks []stack
+		for _, stack := range stacks {
+			if strings.HasSuffix(stack.Name, fmt.Sprintf(":%s", options.Environment)) || strings.HasPrefix(stack.Name, fmt.Sprintf("%s/", options.Environment)) {
+				filteredStacks = append(filteredStacks, stack)
+			}
+		}
+		stacks = filteredStacks
+	}
+
+	if len(stacks) == 0 {
+		logging.Logger.Warn().Msgf("no Spacelift stack found for module path %q with environment %q", options.ModulePath, options.Environment)
+		return nil, nil
+	}
+
+	if len(stacks) > 1 {
+		logging.Logger.Warn().Msgf("found multiple Spacelift stacks for module path %q with environment %q, skipping Spacelift remote variable loading", options.ModulePath, options.Environment)
+		return nil, nil
+	}
+	stack := stacks[0]
+	prevOptions, hit := s.hitMap.Load(stack.ID)
+	if hit {
+		logging.Logger.Debug().Msgf("spacelift stack %q already used for options %+v will not load remote variables", stack.ID, prevOptions)
+		return nil, nil
+	}
+
+	s.hitMap.Store(stack.ID, options)
+
+	logging.Logger.Debug().Msgf("found Spacelift stack %q for module path %q with environment: %q", stack.Name, options.ModulePath, options.Environment)
+
 	vars := map[string]cty.Value{}
-	for _, env := range stackEnvs {
-		vars[env.ID] = cty.StringVal(env.Value)
+
+	// Spacelift precedence is runtime config > config > attached contexts
+	for _, env := range stacks[0].AttachedContexts {
+		if strings.HasPrefix(env.ID, "TF_VAR_") {
+			vars[strings.TrimPrefix(env.ID, "TF_VAR_")] = cty.StringVal(env.ContextName)
+		}
+	}
+
+	for _, env := range stacks[0].Config {
+		if strings.HasPrefix(env.ID, "TF_VAR_") {
+			vars[strings.TrimPrefix(env.ID, "TF_VAR_")] = cty.StringVal(env.Value)
+		}
+	}
+
+	for _, env := range stacks[0].RuntimeConfig {
+		if strings.HasPrefix(env.Element.ID, "TF_VAR_") {
+			vars[strings.TrimPrefix(env.Element.ID, "TF_VAR_")] = cty.StringVal(env.Element.Value)
+		}
+	}
+
+	logging.Logger.Debug().Msgf("loaded %d Spacelift remote variables", len(vars))
+
+	// Only marshal and log the variables if the log level is trace
+	// Otherwise we want to skip the marshalling for performance reasons
+	if logging.Logger.GetLevel() == zerolog.TraceLevel {
+		s := ctyJson.SimpleJSONValue{Value: cty.ObjectVal(vars)}
+		b, _ := s.MarshalJSON()
+		logging.Logger.Trace().Msgf("Spacelift remote variables: %v", string(b))
 	}
 
 	return vars, nil
 }
 
 type stack struct {
-	ID     string        `graphql:"id" json:"id,omitempty"`
-	Name   string        `graphql:"name" json:"name,omitempty"`
-	Config []stackConfig `graphql:"config" json:"config,omitempty"`
+	ID               string            `graphql:"id" json:"id,omitempty"`
+	Name             string            `graphql:"name" json:"name,omitempty"`
+	ProjectRoot      string            `graphql:"projectRoot" json:"projectRoot,omitempty"`
+	Config           []stackConfig     `graphql:"config" json:"config,omitempty"`
+	RuntimeConfig    []runtimeConfig   `graphql:"runtimeConfig" json:"runtimeConfig,omitempty"`
+	AttachedContexts []attachedContext `graphql:"attachedContexts" json:"attachedContexts,omitempty"`
 }
 
 type stackConfig struct {
@@ -449,11 +505,20 @@ type stackConfig struct {
 	Value string `graphql:"value" json:"value,omitempty"`
 }
 
+type runtimeConfig struct {
+	Element stackConfig `graphql:"element" json:"element,omitempty"`
+}
+
+type attachedContext struct {
+	ID          string `graphql:"id" json:"id,omitempty"`
+	ContextName string `graphql:"contextName" json:"contextName,omitempty"`
+}
+
 type getStackOptions struct {
 	count int32
 
 	repositoryName string
-	name           string
+	projectRoot    string
 }
 
 func (s *SpaceliftRemoteVariableLoader) getStacks(ctx context.Context, p *getStackOptions) ([]stack, error) {
@@ -478,21 +543,21 @@ func (s *SpaceliftRemoteVariableLoader) getStacks(ctx context.Context, p *getSta
 			},
 		})
 	}
-
-	if p.name != "" {
+	if p.projectRoot != "" {
 		conditions = append(conditions, structs.QueryPredicate{
-			Field: graphql.String("name"),
+			Field: graphql.String("projectRoot"),
 			Constraint: structs.QueryFieldConstraint{
-				StringMatches: &[]graphql.String{graphql.String(p.name)},
+				StringMatches: &[]graphql.String{graphql.String(p.projectRoot)},
 			},
 		})
-
 	}
 
-	variables := map[string]interface{}{"input": structs.SearchInput{
+	input := structs.SearchInput{
 		First:      graphql.NewInt(graphql.Int(p.count)),
 		Predicates: &conditions,
-	}}
+	}
+
+	variables := map[string]interface{}{"input": input}
 
 	if err := s.Client.Query(
 		ctx,
