@@ -105,18 +105,36 @@ func convertOutputResources(outResources []Resource, skip bool) []*schema.Resour
 	resources := make([]*schema.Resource, len(outResources))
 
 	for i, resource := range outResources {
+
+		var tagProp *schema.TagPropagation
+		if resource.TagPropagation != nil {
+			tagProp = &schema.TagPropagation{
+				To:                    resource.TagPropagation.To,
+				From:                  resource.TagPropagation.From,
+				Tags:                  resource.TagPropagation.Tags,
+				Attribute:             resource.TagPropagation.Attribute,
+				HasRequiredAttributes: resource.TagPropagation.HasRequiredAttributes,
+			}
+		}
+
 		resources[i] = &schema.Resource{
-			Name:             resource.Name,
-			IsSkipped:        skip,
-			Metadata:         convertMetadata(resource.Metadata),
-			CostComponents:   convertCostComponents(resource.CostComponents),
-			ActualCosts:      convertActualCosts(resource.ActualCosts),
-			SubResources:     convertOutputResources(resource.SubResources, skip),
-			Tags:             resource.Tags,
-			HourlyCost:       resource.HourlyCost,
-			MonthlyCost:      resource.MonthlyCost,
-			MonthlyUsageCost: resource.MonthlyUsageCost,
-			ResourceType:     resource.ResourceType,
+			Name:                                    resource.Name,
+			IsSkipped:                               skip,
+			Metadata:                                convertMetadata(resource.Metadata),
+			CostComponents:                          convertCostComponents(resource.CostComponents),
+			ActualCosts:                             convertActualCosts(resource.ActualCosts),
+			SubResources:                            convertOutputResources(resource.SubResources, skip),
+			Tags:                                    resource.Tags,
+			DefaultTags:                             resource.DefaultTags,
+			TagPropagation:                          tagProp,
+			ProviderSupportsDefaultTags:             resource.ProviderSupportsDefaultTags,
+			ProviderLink:                            resource.ProviderLink,
+			HourlyCost:                              resource.HourlyCost,
+			MonthlyCost:                             resource.MonthlyCost,
+			MonthlyUsageCost:                        resource.MonthlyUsageCost,
+			ResourceType:                            resource.ResourceType,
+			MissingVarsCausingUnknownTagKeys:        resource.MissingVarsCausingUnknownTagKeys,
+			MissingVarsCausingUnknownDefaultTagKeys: resource.MissingVarsCausingUnknownDefaultTagKeys,
 		}
 	}
 
@@ -290,18 +308,31 @@ type ActualCosts struct {
 }
 
 type Resource struct {
-	Name             string                 `json:"name"`
-	ResourceType     string                 `json:"resourceType,omitempty"`
-	Tags             *map[string]string     `json:"tags,omitempty"`
-	Metadata         map[string]interface{} `json:"metadata"`
-	HourlyCost       *decimal.Decimal       `json:"hourlyCost,omitempty"`
-	MonthlyCost      *decimal.Decimal       `json:"monthlyCost,omitempty"`
-	MonthlyUsageCost *decimal.Decimal       `json:"monthlyUsageCost,omitempty"`
-	CostComponents   []CostComponent        `json:"costComponents,omitempty"`
-	ActualCosts      []ActualCosts          `json:"actualCosts,omitempty"`
-	SubResources     []Resource             `json:"subresources,omitempty"`
+	Name                                    string                 `json:"name"`
+	ResourceType                            string                 `json:"resourceType,omitempty"`
+	Tags                                    *map[string]string     `json:"tags,omitempty"`
+	DefaultTags                             *map[string]string     `json:"defaultTags,omitempty"`
+	TagPropagation                          *TagPropagation        `json:"tagPropagation,omitempty"`
+	ProviderSupportsDefaultTags             bool                   `json:"providerSupportsDefaultTags,omitempty"`
+	ProviderLink                            string                 `json:"providerLink,omitempty"`
+	Metadata                                map[string]interface{} `json:"metadata"`
+	HourlyCost                              *decimal.Decimal       `json:"hourlyCost,omitempty"`
+	MonthlyCost                             *decimal.Decimal       `json:"monthlyCost,omitempty"`
+	MonthlyUsageCost                        *decimal.Decimal       `json:"monthlyUsageCost,omitempty"`
+	CostComponents                          []CostComponent        `json:"costComponents,omitempty"`
+	ActualCosts                             []ActualCosts          `json:"actualCosts,omitempty"`
+	SubResources                            []Resource             `json:"subresources,omitempty"`
+	MissingVarsCausingUnknownTagKeys        []string               `json:"missingVarsCausingUnknownTagKeys,omitempty"`
+	MissingVarsCausingUnknownDefaultTagKeys []string               `json:"missingVarsCausingUnknownDefaultTagKeys,omitempty"`
 }
 
+type TagPropagation struct {
+	To                    string             `json:"to"`
+	From                  *string            `json:"from,omitempty"`
+	Tags                  *map[string]string `json:"tags,omitempty"`
+	Attribute             string             `json:"attribute"`
+	HasRequiredAttributes bool               `json:"hasRequiredAttributes,omitempty"`
+}
 type Summary struct {
 	TotalResources            *int `json:"totalResources,omitempty"`
 	TotalDetectedResources    *int `json:"totalDetectedResources,omitempty"`
@@ -517,17 +548,34 @@ func newResource(r *schema.Resource, comps []CostComponent, actualCosts []Actual
 		metadata[k] = v.Value()
 	}
 
+	var tagProp *TagPropagation
+	if r.TagPropagation != nil {
+		tagProp = &TagPropagation{
+			To:                    r.TagPropagation.To,
+			From:                  r.TagPropagation.From,
+			Tags:                  r.TagPropagation.Tags,
+			Attribute:             r.TagPropagation.Attribute,
+			HasRequiredAttributes: r.TagPropagation.HasRequiredAttributes,
+		}
+	}
+
 	return Resource{
-		Name:             r.Name,
-		ResourceType:     r.ResourceType,
-		Metadata:         metadata,
-		Tags:             r.Tags,
-		HourlyCost:       r.HourlyCost,
-		MonthlyCost:      r.MonthlyCost,
-		MonthlyUsageCost: r.MonthlyUsageCost,
-		CostComponents:   comps,
-		ActualCosts:      actualCosts,
-		SubResources:     subresources,
+		Name:                                    r.Name,
+		ResourceType:                            r.ResourceType,
+		Metadata:                                metadata,
+		Tags:                                    r.Tags,
+		DefaultTags:                             r.DefaultTags,
+		TagPropagation:                          tagProp,
+		ProviderSupportsDefaultTags:             r.ProviderSupportsDefaultTags,
+		ProviderLink:                            r.ProviderLink,
+		HourlyCost:                              r.HourlyCost,
+		MonthlyCost:                             r.MonthlyCost,
+		MonthlyUsageCost:                        r.MonthlyUsageCost,
+		CostComponents:                          comps,
+		ActualCosts:                             actualCosts,
+		SubResources:                            subresources,
+		MissingVarsCausingUnknownTagKeys:        r.MissingVarsCausingUnknownTagKeys,
+		MissingVarsCausingUnknownDefaultTagKeys: r.MissingVarsCausingUnknownDefaultTagKeys,
 	}
 }
 
