@@ -17,11 +17,10 @@ import (
 	"github.com/infracost/infracost/internal/ui"
 
 	"github.com/shopspring/decimal"
-	"github.com/tidwall/gjson"
 )
 
 var (
-	batchSize = 5
+	batchSize = 1000
 )
 
 // notFoundData represents a single price not found entry
@@ -35,20 +34,22 @@ type notFoundData struct {
 // data. This is used to provide a summary of missing prices at the end of a run.
 // It should be used as a singleton which is shared across the application.
 type PriceFetcher struct {
-	resources  map[string]*notFoundData
-	components map[string]int
-	mux        *sync.RWMutex
-	client     *apiclient.PricingAPIClient
-	runCtx     *config.RunContext
+	resources         map[string]*notFoundData
+	components        map[string]int
+	mux               *sync.RWMutex
+	client            *apiclient.PricingAPIClient
+	runCtx            *config.RunContext
+	warnOnPriceErrors bool
 }
 
-func NewPriceFetcher(ctx *config.RunContext) *PriceFetcher {
+func NewPriceFetcher(ctx *config.RunContext, warnOnPriceErrors bool) *PriceFetcher {
 	return &PriceFetcher{
-		resources:  make(map[string]*notFoundData),
-		components: make(map[string]int),
-		mux:        &sync.RWMutex{},
-		runCtx:     ctx,
-		client:     apiclient.NewPricingAPIClient(ctx),
+		resources:         make(map[string]*notFoundData),
+		components:        make(map[string]int),
+		mux:               &sync.RWMutex{},
+		runCtx:            ctx,
+		client:            apiclient.GetPricingAPIClient(ctx),
+		warnOnPriceErrors: warnOnPriceErrors,
 	}
 }
 
@@ -143,7 +144,7 @@ func (p *PriceFetcher) LogWarnings() {
 		return
 	}
 
-	var data []*notFoundData
+	data := make([]*notFoundData, 0, len(p.resources))
 	for _, v := range p.resources {
 		data = append(data, v)
 	}
@@ -200,7 +201,7 @@ func (p *PriceFetcher) PopulatePrices(project *schema.Project) error {
 
 // getPricesConcurrent gets the prices of all resources concurrently.
 // Concurrency level is calculated using the following formula:
-// max(min(4, numCPU * 4), 16)
+// min(max(4, numCPU * 4), 16)
 func (p *PriceFetcher) getPricesConcurrent(resources []*schema.Resource) error {
 	// Set the number of workers
 	numWorkers := 4
@@ -212,7 +213,7 @@ func (p *PriceFetcher) getPricesConcurrent(resources []*schema.Resource) error {
 		numWorkers = 16
 	}
 
-	reqs := p.client.BatchRequests(resources, batchSize)
+	reqs := p.client.BatchRequests(resources, batchSize, p.runCtx.Config.Currency)
 
 	numJobs := len(reqs)
 	jobs := make(chan apiclient.BatchRequest, numJobs)
@@ -233,6 +234,8 @@ func (p *PriceFetcher) getPricesConcurrent(resources []*schema.Resource) error {
 		jobs <- r
 	}
 
+	close(jobs)
+
 	// Get the result of the jobs
 	for i := 0; i < numJobs; i++ {
 		err := <-resultErrors
@@ -240,6 +243,9 @@ func (p *PriceFetcher) getPricesConcurrent(resources []*schema.Resource) error {
 			return err
 		}
 	}
+
+	close(resultErrors)
+
 	return nil
 }
 
@@ -256,10 +262,28 @@ func (p *PriceFetcher) getPrices(req apiclient.BatchRequest) error {
 	return nil
 }
 
+func (p *PriceFetcher) logPriceLookupErr(cc *schema.CostComponent, format string, v ...interface{}) {
+	if p.warnOnPriceErrors {
+		productFilterJson, _ := json.Marshal(cc.ProductFilter)
+		priceFilterJson, _ := json.Marshal(cc.PriceFilter)
+		logging.Logger.Warn().Msgf(format+". Product filter: %s Price filter:%s", append(v, productFilterJson, priceFilterJson)...)
+
+	} else {
+		logging.Logger.Debug().Msgf(format, v...)
+	}
+}
+
+type productPrice struct {
+	Hash  string
+	Price decimal.Decimal
+}
+
 func (p *PriceFetcher) setCostComponentPrice(result apiclient.PriceQueryResult) {
-	currency := p.client.Currency
+	currency := p.runCtx.Config.Currency
+	if currency == "" {
+		currency = "USD"
+	}
 
-	var pp decimal.Decimal
 	if result.CostComponent.CustomPrice() != nil {
 		logging.Logger.Debug().Msgf("Using user-defined custom price %v for %s %s.", *result.CostComponent.CustomPrice(), result.Resource.Name, result.CostComponent.Name)
 		result.CostComponent.SetPrice(*result.CostComponent.CustomPrice())
@@ -273,6 +297,7 @@ func (p *PriceFetcher) setCostComponentPrice(result apiclient.PriceQueryResult)
 			result.Resource.RemoveCostComponent(result.CostComponent)
 			return
 		}
+		p.logPriceLookupErr(result.CostComponent, "No products found for %s %s", result.Resource.Name, result.CostComponent.Name)
 
 		p.addNotFoundResult(result)
 		return
@@ -284,44 +309,83 @@ func (p *PriceFetcher) setCostComponentPrice(result apiclient.PriceQueryResult)
 
 	// Some resources may have identical records in CPAPI for the same product
 	// filters, several products are always returned and they can only be
-	// distinguished by their prices. However if we pick the first product it may not
+	// distinguished by their prices. However, if we pick the first product it may not
 	// have the price due to price filter and the lookup fails. Filtering the
-	// products with prices helps to solve that.
-	var productsWithPrices []gjson.Result
+	// products with prices helps to solve that. To make sure we get a consistent price
+	// between runs, we sort any multiple prices so we always pick the smallest non-zero
+	// price first.
+	var productPrices [][]productPrice
+	distinctPrices := map[string]bool{}
 	for _, product := range products {
-		if len(product.Get("prices").Array()) > 0 {
-			productsWithPrices = append(productsWithPrices, product)
+		pricesResults := product.Get("prices").Array()
+		if len(pricesResults) > 0 {
+			// map pricesResults to decimals
+			var prices []productPrice
+			for _, price := range pricesResults {
+				priceStr := price.Get(currency).String()
+				p, err := decimal.NewFromString(priceStr)
+				if err != nil {
+					logging.Logger.Warn().Msgf("Error converting price to '%v' (using 0.00)  '%v': %s", currency, price.Get(currency).String(), err.Error())
+					prices = append(prices, productPrice{Hash: price.Get("priceHash").String(), Price: decimal.Zero})
+					continue
+				}
+				prices = append(prices, productPrice{Hash: price.Get("priceHash").String(), Price: p})
+
+				distinctPrices[priceStr] = true
+			}
+
+			// sort prices with the smallest non-zero price first
+			sort.Slice(prices, func(i, j int) bool {
+				if prices[i].Price.IsZero() {
+					return false // Treat zero as larger, so it goes to the end
+				}
+				if prices[j].Price.IsZero() {
+					return true // Non-zero should come before zero
+				}
+				// Both prices are non-zero, sort in ascending order
+				return prices[i].Price.LessThan(prices[j].Price)
+			})
+
+			productPrices = append(productPrices, prices)
 		}
 	}
 
-	if len(productsWithPrices) == 0 {
+	// sort productPrices with the smallest non-zero price first
+	sort.Slice(productPrices, func(i, j int) bool {
+		if productPrices[i][0].Price.IsZero() {
+			return false // Treat zero as larger, so it goes to the end
+		}
+		if productPrices[j][0].Price.IsZero() {
+			return true // Non-zero should come before zero
+		}
+		// Both prices are non-zero, sort in ascending order
+		return productPrices[i][0].Price.LessThan(productPrices[j][0].Price)
+	})
+
+	if len(productPrices) == 0 {
 		if result.CostComponent.IgnoreIfMissingPrice {
 			logging.Logger.Debug().Msgf("No prices found for %s %s, ignoring since IgnoreIfMissingPrice is set.", result.Resource.Name, result.CostComponent.Name)
 			result.Resource.RemoveCostComponent(result.CostComponent)
 			return
 		}
+		p.logPriceLookupErr(result.CostComponent, "No prices found for %s %s", result.Resource.Name, result.CostComponent.Name)
 
 		p.addNotFoundResult(result)
 		return
 	}
 
-	if len(productsWithPrices) > 1 {
-		logging.Logger.Debug().Msgf("Multiple products with prices found for %s %s, using the first product", result.Resource.Name, result.CostComponent.Name)
+	if len(distinctPrices) > 1 {
+		// only worry about duplicate products/prices if they have different prices.
+
+		if len(productPrices) > 1 {
+			p.logPriceLookupErr(result.CostComponent, "Multiple products with prices found for %s %s, using the smallest non-zero price", result.Resource.Name, result.CostComponent.Name)
+		}
+
+		if len(productPrices[0]) > 1 {
+			p.logPriceLookupErr(result.CostComponent, "Multiple prices found for %s %s, using the smallest non-zero price", result.Resource.Name, result.CostComponent.Name)
+		}
 	}
 
-	prices := productsWithPrices[0].Get("prices").Array()
-	if len(prices) > 1 {
-		logging.Logger.Debug().Msgf("Multiple prices found for %s %s, using the first price", result.Resource.Name, result.CostComponent.Name)
-	}
-
-	var err error
-	pp, err = decimal.NewFromString(prices[0].Get(currency).String())
-	if err != nil {
-		logging.Logger.Warn().Msgf("Error converting price to '%v' (using 0.00)  '%v': %s", currency, prices[0].Get(currency).String(), err.Error())
-		result.CostComponent.SetPrice(decimal.Zero)
-		return
-	}
-
-	result.CostComponent.SetPrice(pp)
-	result.CostComponent.SetPriceHash(prices[0].Get("priceHash").String())
+	result.CostComponent.SetPrice(productPrices[0][0].Price)
+	result.CostComponent.SetPriceHash(productPrices[0][0].Hash)
 }
