@@ -9,7 +9,6 @@ import (
 	"sync"
 
 	"github.com/awslabs/goformation/v7"
-
 	"github.com/infracost/infracost/internal/config"
 	"github.com/infracost/infracost/internal/hcl"
 	"github.com/infracost/infracost/internal/logging"
@@ -21,6 +20,7 @@ import (
 type DetectionOutput struct {
 	Providers   []schema.Provider
 	RootModules int
+	Tree        string
 }
 
 // Detect returns a list of providers for the given path. Multiple returned
@@ -77,6 +77,7 @@ func Detect(ctx *config.RunContext, project *config.Project, includePastResource
 		MaxSearchDepth:             ctx.Config.Autodetect.MaxSearchDepth,
 		ForceProjectType:           ctx.Config.Autodetect.ForceProjectType,
 		TerraformVarFileExtensions: ctx.Config.Autodetect.TerraformVarFileExtensions,
+		PreferFolderNameForEnv:     ctx.Config.Autodetect.PreferFolderNameForEnv,
 	}
 
 	// if the config file path is set, we should set the project locator to use the
@@ -88,9 +89,11 @@ func Detect(ctx *config.RunContext, project *config.Project, includePastResource
 	}
 
 	pl := hcl.NewProjectLocator(logging.Logger, locatorConfig)
-	rootPaths := pl.FindRootModules(project.Path)
+	rootPaths, tree := pl.FindRootModules(project.Path)
 	if len(rootPaths) == 0 {
-		return &DetectionOutput{}, fmt.Errorf("could not detect path type for '%s'", project.Path)
+		return &DetectionOutput{
+			Tree: tree,
+		}, fmt.Errorf("could not detect path type for '%s'", project.Path)
 	}
 
 	var autoProviders []schema.Provider
@@ -110,7 +113,7 @@ func Detect(ctx *config.RunContext, project *config.Project, includePastResource
 		}
 	}
 
-	return &DetectionOutput{Providers: autoProviders, RootModules: len(rootPaths)}, nil
+	return &DetectionOutput{Providers: autoProviders, RootModules: len(rootPaths), Tree: tree}, nil
 }
 
 // configFileRootToProvider returns a provider for the given root path which is
@@ -159,7 +162,7 @@ func autodetectedRootToProviders(projectContext *config.ProjectContext, rootPath
 				append(
 					options,
 					hcl.OptionWithTFVarsPaths(append(autoVarFiles.ToPaths(), env.TerraformVarFiles.ToPaths()...), true),
-					hcl.OptionWithModuleSuffix(env.Name),
+					hcl.OptionWithModuleSuffix(rootPath.DetectedPath, env.Name),
 				)...)
 			if err != nil {
 				logging.Logger.Warn().Err(err).Msgf("could not initialize provider for path %q", rootPath.DetectedPath)
