@@ -7,17 +7,15 @@ import (
 
 func getACMPCACertificateAuthorityRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_acmpca_certificate_authority",
-		RFunc: NewACMPCACertificateAuthority,
+		Name:      "aws_acmpca_certificate_authority",
+		CoreRFunc: NewACMPCACertificateAuthority,
 	}
 }
-func NewACMPCACertificateAuthority(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewACMPCACertificateAuthority(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.ACMPCACertificateAuthority{
 		Address:   d.Address,
 		Region:    d.Get("region").String(),
 		UsageMode: d.Get("usage_mode").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
