@@ -7,18 +7,16 @@ import (
 
 func getAPIGatewayStageRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_api_gateway_stage",
-		RFunc: NewAPIGatewayStage,
+		Name:      "aws_api_gateway_stage",
+		CoreRFunc: NewAPIGatewayStage,
 	}
 }
-func NewAPIGatewayStage(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewAPIGatewayStage(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.APIGatewayStage{
 		Address:          d.Address,
 		Region:           d.Get("region").String(),
 		CacheClusterSize: d.Get("cache_cluster_size").Float(),
 		CacheEnabled:     d.GetBoolOrDefault("cache_cluster_enabled", false),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
