@@ -7,17 +7,15 @@ import (
 
 func getAPIGatewayV2APIRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_apigatewayv2_api",
-		RFunc: NewAPIGatewayV2API,
+		Name:      "aws_apigatewayv2_api",
+		CoreRFunc: NewAPIGatewayV2API,
 	}
 }
-func NewAPIGatewayV2API(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewAPIGatewayV2API(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.APIGatewayV2API{
 		Address:      d.Address,
 		ProtocolType: d.Get("protocol_type").String(),
 		Region:       d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
