@@ -7,16 +7,14 @@ import (
 
 func getCloudwatchLogGroupItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_cloudwatch_log_group",
-		RFunc: NewCloudwatchLogGroup,
+		Name:      "aws_cloudwatch_log_group",
+		CoreRFunc: NewCloudwatchLogGroup,
 	}
 }
-func NewCloudwatchLogGroup(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewCloudwatchLogGroup(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.CloudwatchLogGroup{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
