@@ -7,16 +7,14 @@ import (
 
 func getConfigOrganizationManagedRuleItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_config_organization_managed_rule",
-		RFunc: NewConfigOrganizationManagedRule,
+		Name:      "aws_config_organization_managed_rule",
+		CoreRFunc: NewConfigOrganizationManagedRule,
 	}
 }
-func NewConfigOrganizationManagedRule(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewConfigOrganizationManagedRule(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.ConfigConfigRule{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
