@@ -7,18 +7,16 @@ import (
 
 func getDocDBClusterRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_docdb_cluster",
-		RFunc: NewDocDBCluster,
+		Name:      "aws_docdb_cluster",
+		CoreRFunc: NewDocDBCluster,
 	}
 
 }
-func NewDocDBCluster(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewDocDBCluster(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.DocDBCluster{
 		Address:               d.Address,
 		Region:                d.Get("region").String(),
 		BackupRetentionPeriod: d.Get("backup_retention_period").Int(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
