@@ -15,7 +15,7 @@ func getECSServiceRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:                "aws_ecs_service",
 		CoreRFunc:           NewECSService,
-		ReferenceAttributes: []string{"cluster", "task_definition"},
+		ReferenceAttributes: []string{"cluster", "task_definition", "aws_ecs_task_set.service"},
 	}
 }
 
@@ -36,6 +36,16 @@ func NewECSService(d *schema.ResourceData) schema.CoreResource {
 		}
 	}
 
+	for _, ref := range d.References("aws_ecs_task_set.service") {
+		for _, setRef := range ref.References("task_definition") {
+			if setRef.Type == "aws_ecs_task_definition" {
+				taskDefinition = setRef
+				break
+			}
+
+		}
+	}
+
 	if taskDefinition != nil {
 		memoryGB = parseVCPUMemoryString(taskDefinition.Get("memory").String())
 		vcpu = parseVCPUMemoryString(taskDefinition.Get("cpu").String())
