@@ -7,16 +7,14 @@ import (
 
 func getNewEKSFargateProfileItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_eks_fargate_profile",
-		RFunc: NewEKSFargateProfile,
+		Name:      "aws_eks_fargate_profile",
+		CoreRFunc: NewEKSFargateProfile,
 	}
 }
-func NewEKSFargateProfile(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewEKSFargateProfile(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.EKSFargateProfile{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
