@@ -6,7 +6,7 @@ import (
 	"github.com/infracost/infracost/internal/providers/terraform/tftest"
 )
 
-func TestKinesisDataAnalyticsGoldenFile(t *testing.T) {
+func TestKinesisAnalyticsV2ApplicationGoldenFile(t *testing.T) {
 	t.Parallel()
 	if testing.Short() {
 		t.Skip("skipping test in short mode")
