@@ -13,12 +13,14 @@ func getRDSClusterRegistryItem() *schema.RegistryItem {
 }
 
 func NewRDSCluster(d *schema.ResourceData) schema.CoreResource {
+	engineMode := d.GetStringOrDefault("engine_mode", "provisioned")
 	r := &aws.RDSCluster{
 		Address:               d.Address,
 		Region:                d.Get("region").String(),
 		Engine:                d.GetStringOrDefault("engine", "aurora"),
 		BackupRetentionPeriod: d.GetInt64OrDefault("backup_retention_period", 1),
-		EngineMode:            d.GetStringOrDefault("engine_mode", "provisioned"),
+		EngineMode:            engineMode,
+		IOOptimized:           d.Get("storage_type").String() == "aurora-iopt1",
 	}
 	return r
 }
