@@ -85,6 +85,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getRoute53ZoneRegistryItem(),
 	getS3BucketAnalyticsConfigurationRegistryItem(),
 	getS3BucketInventoryRegistryItem(),
+	getS3BucketIntelligentTieringConfigurationRegistryItem(),
 	getS3BucketLifecycleConfigurationRegistryItem(),
 	getS3BucketRegistryItem(),
 	getS3BucketVersioningRegistryItem(),
@@ -122,6 +123,7 @@ var ResourceRegistry []*schema.RegistryItem = []*schema.RegistryItem{
 	getSchedulerScheduleRegistryItem(),
 	getPipesPipeRegistryItem(),
 	getCloudwatchEventTargetRegistryItem(),
+	getCloudfrontFunctionRegistryItem(),
 }
 
 // FreeResources grouped alphabetically
@@ -530,7 +532,6 @@ var FreeResources = []string{
 	"aws_s3_account_public_access_block",
 	"aws_s3_bucket_acl",
 	"aws_s3_bucket_cors_configuration",
-	"aws_s3_bucket_intelligent_tiering_configuration",
 	"aws_s3_bucket_logging",
 	"aws_s3_bucket_metric",
 	"aws_s3_bucket_notification",
