@@ -7,17 +7,15 @@ import (
 
 func getSecretsManagerSecret() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "aws_secretsmanager_secret",
-		RFunc: NewSecretsManagerSecret,
+		Name:      "aws_secretsmanager_secret",
+		CoreRFunc: NewSecretsManagerSecret,
 	}
 }
 
-func NewSecretsManagerSecret(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewSecretsManagerSecret(d *schema.ResourceData) schema.CoreResource {
 	r := &aws.SecretsManagerSecret{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
