@@ -8,12 +8,12 @@ import (
 func getSNSTopicRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
 		Name:                "aws_sns_topic",
-		RFunc:               NewSNSTopic,
+		CoreRFunc:           NewSNSTopic,
 		ReferenceAttributes: []string{"aws_sns_topic_subscription.topic_arn"},
 	}
 }
 
-func NewSNSTopic(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewSNSTopic(d *schema.ResourceData) schema.CoreResource {
 	if d.GetBoolOrDefault("fifo_topic", false) {
 		r := &aws.SNSFIFOTopic{
 			Address:       d.Address,
@@ -21,14 +21,12 @@ func NewSNSTopic(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
 			Subscriptions: int64(len(d.References("aws_sns_topic_subscription.topic_arn"))),
 		}
 
-		r.PopulateUsage(u)
-		return r.BuildResource()
+		return r
 	}
 
 	r := &aws.SNSTopic{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
