@@ -7,10 +7,10 @@ import (
 )
 
 func TestSNSTopicGoldenFile(t *testing.T) {
-	t.Parallel()
 	if testing.Short() {
 		t.Skip("skipping test in short mode")
 	}
-
-	tftest.GoldenFileResourceTests(t, "sns_topic_test")
+	opts := tftest.DefaultGoldenFileOptions()
+	opts.CaptureLogs = true
+	tftest.GoldenFileResourceTestsWithOpts(t, "sns_topic_test", opts)
 }
