@@ -7,12 +7,11 @@ import (
 
 func getAppServiceCertificateOrderRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_app_service_certificate_order",
-		RFunc: NewAppServiceCertificateOrder,
+		Name:      "azurerm_app_service_certificate_order",
+		CoreRFunc: NewAppServiceCertificateOrder,
 	}
 }
-func NewAppServiceCertificateOrder(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewAppServiceCertificateOrder(d *schema.ResourceData) schema.CoreResource {
 	r := &azure.AppServiceCertificateOrder{Address: d.Address, ProductType: d.Get("product_type").String()}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
