@@ -14,7 +14,7 @@ func GetAzureRMHDInsightInteractiveQueryClusterRegistryItem() *schema.RegistryIt
 }
 
 func NewAzureRMHDInsightInteractiveQueryCluster(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := lookupRegion(d, []string{})
+	region := d.Region
 
 	costComponents := []*schema.CostComponent{}
 
