@@ -17,7 +17,7 @@ func GetAzureRMAppIntegrationServiceEnvironmentRegistryItem() *schema.RegistryIt
 }
 
 func NewAzureRMIntegrationServiceEnvironment(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
-	region := lookupRegion(d, []string{})
+	region := d.Region
 
 	productName := "Logic Apps Integration Service Environment"
 	skuName := d.Get("sku_name").String()
