@@ -11,8 +11,12 @@ func TestAzureRMLoadBalancerOutboundRuleGoldenFile(t *testing.T) {
 	if testing.Short() {
 		t.Skip("skipping test in short mode")
 	}
+	opts := tftest.DefaultGoldenFileOptions()
 
-	tftest.GoldenFileResourceTests(t, "lb_outbound_rule_test")
+	// Skip CLI diff as it yields different results
+	opts.IgnoreCLI = true
+
+	tftest.GoldenFileResourceTestsWithOpts(t, "lb_outbound_rule_test", opts)
 }
 
 func TestAzureRMLoadBalancerOutboundRuleV2GoldenFile(t *testing.T) {
@@ -21,5 +25,10 @@ func TestAzureRMLoadBalancerOutboundRuleV2GoldenFile(t *testing.T) {
 		t.Skip("skipping test in short mode")
 	}
 
-	tftest.GoldenFileResourceTests(t, "lb_outbound_rule_v2_test")
+	opts := tftest.DefaultGoldenFileOptions()
+
+	// Skip CLI diff as it yields different results
+	opts.IgnoreCLI = true
+
+	tftest.GoldenFileResourceTestsWithOpts(t, "lb_outbound_rule_v2_test", opts)
 }
