@@ -12,7 +12,11 @@ func TestAzureRMLoadBalancerRuleGoldenFile(t *testing.T) {
 		t.Skip("skipping test in short mode")
 	}
 
-	tftest.GoldenFileResourceTests(t, "lb_rule_test")
+	opts := tftest.DefaultGoldenFileOptions()
+	// Skip CLI diff as it yields different results
+	opts.IgnoreCLI = true
+
+	tftest.GoldenFileResourceTestsWithOpts(t, "lb_rule_test", opts)
 }
 
 func TestAzureRMLoadBalancerRuleV2GoldenFile(t *testing.T) {
@@ -21,5 +25,9 @@ func TestAzureRMLoadBalancerRuleV2GoldenFile(t *testing.T) {
 		t.Skip("skipping test in short mode")
 	}
 
-	tftest.GoldenFileResourceTests(t, "lb_rule_v2_test")
+	opts := tftest.DefaultGoldenFileOptions()
+	// Skip CLI diff as it yields different results
+	opts.IgnoreCLI = true
+
+	tftest.GoldenFileResourceTestsWithOpts(t, "lb_rule_v2_test", opts)
 }
