@@ -16,7 +16,7 @@ func getMonitorMetricAlertRegistryItem() *schema.RegistryItem {
 }
 
 func newMonitorMetricAlert(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 
 	scopeCount := 1 // default scope is the azure subscription, so count == 1
 	if !d.IsEmpty("scopes") {
