@@ -18,7 +18,7 @@ func getPrivateDnsResolverInboundEndpointRegistryItem() *schema.RegistryItem {
 }
 
 func newPrivateDnsResolverInboundEndpoint(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 
 	if strings.HasPrefix(strings.ToLower(region), "usgov") {
 		region = "US Gov Zone 1"
