@@ -11,7 +11,7 @@ func getServicePlanRegistryItem() *schema.RegistryItem {
 		CoreRFunc: func(d *schema.ResourceData) schema.CoreResource {
 			return &azure.ServicePlan{
 				Address:     d.Address,
-				Region:      lookupRegion(d, []string{}),
+				Region:      d.Region,
 				SKUName:     d.Get("sku_name").String(),
 				WorkerCount: d.GetInt64OrDefault("worker_count", 1),
 				OSType:      d.Get("os_type").String(),
