@@ -16,7 +16,7 @@ func getSignalRServiceRegistryItem() *schema.RegistryItem {
 }
 
 func newSignalRService(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 	return &azure.SignalRService{
 		Address:     d.Address,
 		Region:      region,
