@@ -17,7 +17,7 @@ func getSnapshotRegistryItem() *schema.RegistryItem {
 }
 
 func newSnapshot(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 
 	return &azure.Image{
 		Type:      "Snapshot",
