@@ -13,5 +13,7 @@ func TestSQLDatabase(t *testing.T) {
 
 	opts := tftest.DefaultGoldenFileOptions()
 	opts.CaptureLogs = true
+	// ignore CLI - this has been removed from the latest provider
+	opts.IgnoreCLI = true
 	tftest.GoldenFileResourceTestsWithOpts(t, "sql_database_test", opts)
 }
