@@ -17,7 +17,7 @@ func getTrafficManagerProfileRegistryItem() *schema.RegistryItem {
 }
 
 func newTrafficManagerProfile(d *schema.ResourceData) schema.CoreResource {
-	region := lookupRegion(d, []string{"resource_group_name"})
+	region := d.Region
 
 	return &azure.TrafficManagerProfile{
 		Address:            d.Address,
