@@ -7,16 +7,16 @@ import (
 
 func getVPNGatewayConnectionRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "azurerm_vpn_gateway_connection",
-		RFunc: newVPNGatewayConnection,
+		Name:      "azurerm_vpn_gateway_connection",
+		CoreRFunc: newVPNGatewayConnection,
 	}
 }
 
-func newVPNGatewayConnection(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func newVPNGatewayConnection(d *schema.ResourceData) schema.CoreResource {
 	v := &azure.VPNGatewayConnection{
 		Address: d.Address,
 		Region:  d.Get("region").String(),
 	}
 
-	return v.BuildResource()
+	return v
 }
