@@ -7,21 +7,20 @@ import (
 
 func getComputeForwardingRuleRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_compute_forwarding_rule",
-		RFunc: NewComputeForwardingRule,
-		Notes: []string{"Price for additional forwarding rule is used"},
+		Name:      "google_compute_forwarding_rule",
+		CoreRFunc: NewComputeForwardingRule,
+		Notes:     []string{"Price for additional forwarding rule is used"},
 	}
 }
 func getComputeGlobalForwardingRuleRegistryItem() *schema.RegistryItem {
 	return &schema.RegistryItem{
-		Name:  "google_compute_global_forwarding_rule",
-		RFunc: NewComputeForwardingRule,
-		Notes: []string{"Price for additional forwarding rule is used"},
+		Name:      "google_compute_global_forwarding_rule",
+		CoreRFunc: NewComputeForwardingRule,
+		Notes:     []string{"Price for additional forwarding rule is used"},
 	}
 }
 
-func NewComputeForwardingRule(d *schema.ResourceData, u *schema.UsageData) *schema.Resource {
+func NewComputeForwardingRule(d *schema.ResourceData) schema.CoreResource {
 	r := &google.ComputeForwardingRule{Address: d.Address, Region: d.Get("region").String()}
-	r.PopulateUsage(u)
-	return r.BuildResource()
+	return r
 }
