@@ -36,7 +36,8 @@ func GetResourceRegion(d *schema.ResourceData) string {
 	return ""
 }
 
-func ParseTags(r *schema.ResourceData) *map[string]string {
+func ParseTags(r *schema.ResourceData, externalTags, defaultLabels map[string]string) (map[string]string, []string) {
+
 	_, supportsLabels := provider_schemas.GoogleLabelsSupport[r.Type]
 	rLabels := r.Get("labels").Map()
 
@@ -46,13 +47,22 @@ func ParseTags(r *schema.ResourceData) *map[string]string {
 	_, supportsSettingsUserLabels := provider_schemas.GoogleSettingsUserLabelsSupport[r.Type]
 	rSettingsUserLabels := r.Get("settings.0.user_labels").Map()
 
+	missingForLabels := schema.ExtractMissingVarsCausingMissingAttributeKeys(r, "labels")
+	missingForUserLabels := schema.ExtractMissingVarsCausingMissingAttributeKeys(r, "user_labels")
+	missingForSettingsUserLabels := schema.ExtractMissingVarsCausingMissingAttributeKeys(r, "settings.0.user_labels")
+	missing := append(append(missingForLabels, missingForUserLabels...), missingForSettingsUserLabels...)
+
 	if !supportsLabels && len(rLabels) == 0 &&
 		!supportsUserLabels && len(rUserLabels) == 0 &&
 		!supportsSettingsUserLabels && len(rSettingsUserLabels) == 0 {
-		return nil
+		return nil, missing
 	}
 
 	tags := make(map[string]string)
+
+	for k, v := range defaultLabels {
+		tags[k] = v
+	}
 	for k, v := range rLabels {
 		tags[k] = v.String()
 	}
@@ -62,5 +72,9 @@ func ParseTags(r *schema.ResourceData) *map[string]string {
 	for k, v := range rSettingsUserLabels {
 		tags[k] = v.String()
 	}
-	return &tags
+	for k, v := range externalTags {
+		tags[k] = v
+	}
+
+	return tags, missing
 }
